@@ -1,36 +1,19 @@
-# vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
-
-# Copyright 2016-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
-# This file is part of qutebrowser.
-#
-# qutebrowser is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# qutebrowser is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """QtWebEngine specific qute://* handlers and glue code."""
 
-from PyQt5.QtCore import QBuffer, QIODevice, QUrl
-from PyQt5.QtWebEngineCore import (QWebEngineUrlSchemeHandler,
-                                   QWebEngineUrlRequestJob)
-try:
-    from PyQt5.QtWebEngineCore import QWebEngineUrlScheme
-except ImportError:
-    # Added in Qt 5.12
-    QWebEngineUrlScheme = None  # type: ignore[misc, assignment]
+from qutebrowser.qt.core import QBuffer, QIODevice, QUrl, QByteArray
+from qutebrowser.qt.webenginecore import (QWebEngineUrlSchemeHandler,
+                                   QWebEngineUrlRequestJob,
+                                   QWebEngineUrlScheme)
 
 from qutebrowser.browser import qutescheme
 from qutebrowser.utils import log, qtutils
 
+_QUTE = QByteArray(b'qute')
+
 
 class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
 
@@ -39,14 +22,9 @@ class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
     def install(self, profile):
         """Install the handler for qute:// URLs on the given profile."""
         if QWebEngineUrlScheme is not None:
-            assert QWebEngineUrlScheme.schemeByName(b'qute') is not None
+            assert QWebEngineUrlScheme.schemeByName(_QUTE) is not None
 
-        profile.installUrlSchemeHandler(b'qute', self)
-        if (qtutils.version_check('5.11', compiled=False) and
-                not qtutils.version_check('5.12', compiled=False)):
-            # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-63378
-            profile.installUrlSchemeHandler(b'chrome-error', self)
-            profile.installUrlSchemeHandler(b'chrome-extension', self)
+        profile.installUrlSchemeHandler(_QUTE, self)
 
     def _check_initiator(self, job):
         """Check whether the initiator of the job should be allowed.
@@ -60,36 +38,23 @@ class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
         Return:
             True if the initiator is allowed, False if it was blocked.
         """
-        try:
-            initiator = job.initiator()
-            request_url = job.requestUrl()
-        except AttributeError:
-            # Added in Qt 5.11
-            return True
+        initiator = job.initiator()
+        request_url = job.requestUrl()
 
         # https://codereview.qt-project.org/#/c/234849/
         is_opaque = initiator == QUrl('null')
         target = request_url.scheme(), request_url.host()
 
-        if is_opaque and not qtutils.version_check('5.12'):
-            # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-70421
-            # When we don't register the qute:// scheme, all requests are
-            # flagged as opaque.
-            return True
-
-        if (target == ('qute', 'testdata') and
-                is_opaque and
-                qtutils.version_check('5.12')):
-            # Allow requests to qute://testdata, as this is needed in Qt 5.12
-            # for all tests to work properly. No qute://testdata handler is
-            # installed outside of tests.
+        if target == ('qute', 'testdata') and is_opaque:
+            # Allow requests to qute://testdata, as this is needed for all tests to work
+            # properly. No qute://testdata handler is installed outside of tests.
             return True
 
         if initiator.isValid() and initiator.scheme() != 'qute':
             log.network.warning("Blocking malicious request from {} to {}"
                                 .format(initiator.toDisplayString(),
                                         request_url.toDisplayString()))
-            job.fail(QWebEngineUrlRequestJob.RequestDenied)
+            job.fail(QWebEngineUrlRequestJob.Error.RequestDenied)
             return False
 
         return True
@@ -105,16 +70,11 @@ class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
         """
         url = job.requestUrl()
 
-        if url.scheme() in ['chrome-error', 'chrome-extension']:
-            # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-63378
-            job.fail(QWebEngineUrlRequestJob.UrlInvalid)
-            return
-
         if not self._check_initiator(job):
             return
 
         if job.requestMethod() != b'GET':
-            job.fail(QWebEngineUrlRequestJob.RequestDenied)
+            job.fail(QWebEngineUrlRequestJob.Error.RequestDenied)
             return
 
         assert url.scheme() == 'qute'
@@ -125,19 +85,18 @@ class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
         except qutescheme.Error as e:
             errors = {
                 qutescheme.NotFoundError:
-                    QWebEngineUrlRequestJob.UrlNotFound,
+                    QWebEngineUrlRequestJob.Error.UrlNotFound,
                 qutescheme.UrlInvalidError:
-                    QWebEngineUrlRequestJob.UrlInvalid,
+                    QWebEngineUrlRequestJob.Error.UrlInvalid,
                 qutescheme.RequestDeniedError:
-                    QWebEngineUrlRequestJob.RequestDenied,
+                    QWebEngineUrlRequestJob.Error.RequestDenied,
                 qutescheme.SchemeOSError:
-                    QWebEngineUrlRequestJob.UrlNotFound,
+                    QWebEngineUrlRequestJob.Error.UrlNotFound,
                 qutescheme.Error:
-                    QWebEngineUrlRequestJob.RequestFailed,
+                    QWebEngineUrlRequestJob.Error.RequestFailed,
             }
             exctype = type(e)
-            log.network.error("{} while handling qute://* URL".format(
-                exctype.__name__))
+            log.network.error(f"{exctype.__name__} while handling qute://* URL: {e}")
             job.fail(errors[exctype])
         except qutescheme.Redirect as e:
             qtutils.ensure_valid(e.url)
@@ -149,7 +108,7 @@ class QuteSchemeHandler(QWebEngineUrlSchemeHandler):
             # because that somehow segfaults...
             # https://www.riverbankcomputing.com/pipermail/pyqt/2016-September/038075.html
             buf = QBuffer(parent=self)
-            buf.open(QIODevice.WriteOnly)
+            buf.open(QIODevice.OpenModeFlag.WriteOnly)
             buf.write(data)
             buf.seek(0)
             buf.close()
@@ -163,9 +122,9 @@ def init():
     classes.
     """
     if QWebEngineUrlScheme is not None:
-        assert not QWebEngineUrlScheme.schemeByName(b'qute').name()
-        scheme = QWebEngineUrlScheme(b'qute')
+        assert not QWebEngineUrlScheme.schemeByName(_QUTE).name()
+        scheme = QWebEngineUrlScheme(_QUTE)
         scheme.setFlags(
-            QWebEngineUrlScheme.LocalScheme |  # type: ignore[arg-type]
-            QWebEngineUrlScheme.LocalAccessAllowed)
+            QWebEngineUrlScheme.Flag.LocalScheme |
+            QWebEngineUrlScheme.Flag.LocalAccessAllowed)
         QWebEngineUrlScheme.registerScheme(scheme)
