@@ -626,7 +626,14 @@ class WebEngineHistoryPrivate(browsertab.AbstractHistoryPrivate):
         return data
 
     def deserialize(self, data):
-        qtutils.deserialize(data, self._history)
+        try:
+            qtutils.deserialize(data, self._history)
+        except OSError:
+            dump = "\n".join(
+                bytes(line).hex(" ") for line in utils.chunk(bytes(data), 16)
+            )
+            log.webview.debug(f"Failed to deserialize history data:\n{dump}")
+            raise
 
     def _load_items_workaround(self, items):
         """WORKAROUND for session loading not working on Qt 5.15.
@@ -1363,6 +1370,11 @@ class WebEngineTab(browsertab.AbstractTab):
             self._widget.page().toHtml(callback)
 
     def run_js_async(self, code, callback=None, *, world=None):
+        if sip.isdeleted(self._widget):
+            # https://github.com/qutebrowser/qutebrowser/issues/3895
+            log.misc.debug("run_js_async called on deleted tab")
+            return
+
         world_id_type = Union[QWebEngineScript.ScriptWorldId, int]
         if world is None:
             world_id: world_id_type = QWebEngineScript.ScriptWorldId.ApplicationWorld
