@@ -15,8 +15,8 @@ try:
 except ImportError:  # pragma: no cover
     try:
         # Python2
-        from Tkinter import Tk  # type: ignore[import, no-redef]
-        import tkMessageBox as messagebox  # type: ignore[import, no-redef] # noqa: N813
+        from Tkinter import Tk  # type: ignore[import-not-found, no-redef]
+        import tkMessageBox as messagebox  # type: ignore[import-not-found, no-redef] # noqa: N813
     except ImportError:
         # Some Python without Tk
         Tk = None  # type: ignore[misc, assignment]
@@ -28,11 +28,11 @@ except ImportError:  # pragma: no cover
 # to stderr.
 def check_python_version():
     """Check if correct python version is run."""
-    if sys.hexversion < 0x03080000:
+    if sys.hexversion < 0x03090000:
         # We don't use .format() and print_function here just in case someone
         # still has < 2.6 installed.
         version_str = '.'.join(map(str, sys.version_info[:3]))
-        text = ("At least Python 3.8 is required to run qutebrowser, but " +
+        text = ("At least Python 3.9 is required to run qutebrowser, but " +
                 "it's running with " + version_str + ".\n")
 
         show_errors = '--no-err-windows' not in sys.argv
